@@ -1,11 +1,12 @@
-from fileformats.generic import File
+from fileformats.generic import BinaryFile
 from .archive import Zip
 from fileformats.core.mixin import WithMagicNumber
 
 
 # Document formats
-class Document(File):
-    iana_mime = None
+class Document(BinaryFile):
+    # iana_mime = None
+    pass
 
 
 class Pdf(WithMagicNumber, Document):
