@@ -1,12 +1,10 @@
 from .core import __version__  # noqa
-from fileformats.generic import File
+from fileformats.generic import BinaryFile
 from fileformats.core.mixin import WithMagicNumber
 
 
-class Audio(File):
+class Audio(BinaryFile):
     "Base class for audio file formats"
-    binary = True
-    iana_mime = None
 
 
 # Compressed formats
@@ -409,7 +407,8 @@ class Fwdred(Audio):
 
 
 class G711_0(WithMagicNumber, Audio):
-    """TODO: #!G7110A\n or #!G7110M\n (for A-law or MU-law
+    """
+    TODO: #!G7110A\\n or #!G7110M\\n (for A-law or MU-law
     encodings respectively, see Section 6)."""
 
     iana_mime = "audio/G711-0"
@@ -612,7 +611,8 @@ class Melp2400(Audio):
 class Mhas(Audio):
     """
 
-    TODO: Receivers can search for the following syncword within the binary data stream: mpeghAudioStreamPacket() 0xC001A5 (24bit sequence)."""
+    TODO: Receivers can search for the following syncword within the binary data stream: mpeghAudioStreamPacket() 0xC001A5 (24bit sequence).
+    """
 
     iana_mime = "audio/mhas"
     ext = ".mhas"
@@ -934,3 +934,126 @@ class VorbisConfig(Audio):
 
     iana_mime = "audio/vorbis-config"
     ext = None
+
+
+__all__ = [
+    "Audio",
+    "Mpeg",
+    "Mp4",
+    "Aac",
+    "Wav",
+    "_1d_interleaved_parityfec",
+    "_32kadpcm",
+    "_3gpp",
+    "_3gpp2",
+    "Ac3",
+    "Amr",
+    "AmrWb",
+    "AmrWb__",
+    "Aptx",
+    "Asc",
+    "AtracAdvancedLossless",
+    "AtracX",
+    "Atrac3",
+    "Basic",
+    "Bv16",
+    "Bv32",
+    "Clearmode",
+    "Cn",
+    "Dat12",
+    "Dls",
+    "DsrEs201108",
+    "DsrEs202050",
+    "DsrEs202211",
+    "DsrEs202212",
+    "Dv",
+    "Dvi4",
+    "Eac3",
+    "Encaprtp",
+    "Evrc",
+    "EvrcQcp",
+    "Evrc0",
+    "Evrc1",
+    "Evrcb",
+    "Evrcb0",
+    "Evrcb1",
+    "Evrcnw",
+    "Evrcnw0",
+    "Evrcnw1",
+    "Evrcwb",
+    "Evrcwb0",
+    "Evrcwb1",
+    "Evs",
+    "Flexfec",
+    "Fwdred",
+    "G711_0",
+    "G719",
+    "G7221",
+    "G722",
+    "G723",
+    "G726_16",
+    "G726_24",
+    "G726_32",
+    "G726_40",
+    "G728",
+    "G729",
+    "G7291",
+    "G729d",
+    "G729e",
+    "Gsm",
+    "GsmEfr",
+    "GsmHr_08",
+    "Ilbc",
+    "IpMrV2_5",
+    "L8",
+    "L16",
+    "L20",
+    "L24",
+    "Lpc",
+    "Melp",
+    "Melp600",
+    "Melp1200",
+    "Melp2400",
+    "Mhas",
+    "MobileXmf",
+    "Mpa",
+    "Mp4a_latm",
+    "MpaRobust",
+    "Mpeg4_generic",
+    "Ogg",
+    "Opus",
+    "Parityfec",
+    "Pcma",
+    "PcmaWb",
+    "Pcmu",
+    "PcmuWb",
+    "Prs_Sid",
+    "Qcelp",
+    "Raptorfec",
+    "Red",
+    "RtpEncAescm128",
+    "Rtploopback",
+    "RtpMidi",
+    "Rtx",
+    "Scip",
+    "Smv",
+    "Smv0",
+    "SmvQcp",
+    "Sofa",
+    "SpMidi",
+    "Speex",
+    "T140c",
+    "T38",
+    "TelephoneEvent",
+    "TetraAcelp",
+    "TetraAcelpBb",
+    "Tone",
+    "Tsvcis",
+    "Uemclip",
+    "Ulpfec",
+    "Usac",
+    "Vdvi",
+    "VmrWb",
+    "Vorbis",
+    "VorbisConfig",
+]
