@@ -1,17 +1,15 @@
-from fileformats.generic import File
+from fileformats.generic import BinaryFile
 from fileformats.core.mixin import WithMagicNumber, WithMagicVersion
 
 
-class Magic(WithMagicNumber, File):
+class Magic(WithMagicNumber, BinaryFile):
 
     ext = ".magic"
-    binary = True
     magic_number = b"MAGIC"
     magic_offset = 10
 
 
-class MagicVersion(WithMagicVersion, File):
+class MagicVersion(WithMagicVersion, BinaryFile):
 
     ext = ".mag.ver"
-    binary = True
     magic_pattern = rb"MAGIC_VERSION{\d\d}\.{\d\d}"
